#pragma once

#include <memory>

namespace precice::m2n {

class M2N;

using PtrM2N = std::shared_ptr<M2N>;

} // namespace precice::m2n
